==> sarg_2.2.6.orig.tar.gz: sarg-2.2.6/include/defs.h <==
// auth.c
void htaccess(const char *name);

// authfail.c
void authfail_report(void);

// charset.c
void ccharset(char *CharSet);

// convlog.c
void convlog(const char *arq, char *df, int dfrom, int duntil);

// css.c
void css(FILE *fp_css);

// dansguardian_log.c
void dansguardian_log(void);

// dansguardian_report.c
void dansguardian_report(void);

// datafile.c
void data_file(char *tmp);

// decomp.c
void decomp(char *arq, char *zip, const char *tmp);
void recomp(const char *arq, const char *zip) ;

// denied.c
void gen_denied_report(void);

// download.c
void download_report(void);

// email.c
int geramail(const char *dirname, int debug, const char *outdir, int userip, const char *email, const char *TempDir);

// exclude.c
int vhexclude(const char *excludefile, const char *url);
int vuexclude(const char *excludeuser, const char *user);

// getconf.c
void getconf(void);

// grepday.c
void greport_day(const char *user);
void greport_cleanup(void);

// html.c
void htmlrel(void);

// indexonly.c
void index_only(const char *dirname,int debug);

// ip2name.c
void ip2name(char *ip,int ip_len);
void name2ip(char *name);

// language.c
void language_load(const char *language);

// lastlog.c
void mklastlog(const char *outdir);

// index.c
void make_index(void);

// realtime.c
void realtime(void);

// repday.c
void report_day(const char *user);

// report.c
void gravatmp(const char *oldaccuser, const char *dirname, const char *oldurl, long long int nacc, long long int nbytes, const char *oldmsg, long long int nelap, int indexonly, long long int incache, long long int oucache);
void gerarel(void);

// siteuser.c
void siteuser(void);

// smartfilter.c
void smartfilter_report(void);

// sort.c
void sort_users_log(const char *tmp, int debug);
void tmpsort(void);

// splitlog.c
void splitlog(const char *arq, char *df, int dfrom, int duntil, char *convert);

// squidguard_log.c
void squidguard_log(void);

// squidguard_report.c
void squidguard_report(void);

// topsites.c
void topsites(void);

// topuser.c
void topuser(void);

// totday.c
void day_totalize(const char *tmp, const char *user, int indexonly);

// totger.c
int totalger(const char *dirname, int debug, const char *outdir);

// usage.c
void usage(const char *prog);

// useragent.c
void useragent(void);

// util.c
int getword(char *word, int limit, char *line, int stop);
int getword_multisep(char *word, int limit, char *line, int stop);
int getword3(char *word, int limit, char *line, int stop);
void name_month(char *month,int month_len);
void conv_month_name(char *month);
void buildymd(const char *dia, const char *mes, const char *ano, char *wdata);
void date_from(char *date, char *dfrom, char *duntil);
int getnumlist( char *, numlist *, const int, const int );
void fixip(char *ip);
char *fixnum(long long int value, int n);
char *fixnum2(long long int value, int n);
void fixnone(char *str);
void fixper(char *tbuf, char *period, const char *duntil);
char *fixtime(long int elap);
void fixendofline(char *str);
void show_info(FILE *fp_ou);
void show_sarg(FILE *fp_ou, const char *ind);
void write_logo_image(FILE *fp_ou);
void write_html_header(FILE *fp_ou, const char * ind);
void write_html_trailer(FILE *fp_ou);
void output_html_string(FILE *fp_ou,const char *str);
void subs(char *str, int size, char *from, char *to);
void conv_month(char *month);
void debuga(const char *msg,...);
void debugaz(const char *head, const char *msg);
void my_lltoa(unsigned long long int n, char s[], int len);
char *get_size(const char *path, const char *file);
void url_module(const char *url, char *w2);
void strip_latin(char *line);
char *buildtime(long long int elap);
void obtdate(const char *dirname, const char *name, char *data);
void obtuser(const char *dirname, const char *name, char *tuser);
void obttotal(const char *dirname, const char *name, char *tbytes, char *tuser, char *media);
void version(void);
int vercode(const char *code);
void load_excludecodes(const char *ExcludeCodes);
void free_excludecodes(void);
void my_mkdir(const char *name);
int testvaliduserchar(const char *user);
char *strlow(char *string);
char *strup(char *string);
void builddia(char *dia, const char *mes, const char *ano, const char *df, char *wdata);
void vrfydir(const char *dir, const char *per1, const char *addr, const char *site, const char *us, const char *form);
void gperiod(const char *dirname, const char *period);
void removetmp(const char *outdir);
void zdate(char *ftime, const char *DateFormat);
void baddata(void);
char *get_param_value(const char *param,char *line);
void read_usertab(const char *UserTabFile);
void get_usertab_name(const char *user,char *name,int namelen);
int compar( const void *, const void * );
int is_download_suffix(const char *url);

==> sarg_2.2.7.1.orig.tar.gz: sarg-2.2.7.1/include/defs.h <==

struct getwordstruct
{
   const char *current;
   const char *beginning;
};

// auth.c
void htaccess(const char *name);

// authfail.c
void authfail_report(void);

// charset.c
void ccharset(char *CharSet);

// convlog.c
void convlog(const char *arq, char *df, int dfrom, int duntil);

// css.c
void css(FILE *fp_css);

// dansguardian_log.c
void dansguardian_log(void);

// dansguardian_report.c
void dansguardian_report(void);

// datafile.c
void data_file(char *tmp);

// decomp.c
void decomp(char *arq, char *zip, const char *tmp);
void recomp(const char *arq, const char *zip) ;

// denied.c
void gen_denied_report(void);

// download.c
void download_report(void);
void free_download(void);
void set_download_suffix(const char *list);
int is_download_suffix(const char *url);

// email.c
int geramail(const char *dirname, int debug, const char *outdir, int userip, const char *email, const char *TempDir);

// exclude.c
void gethexclude(const char *hexfile, int debug);
void getuexclude(const char *uexfile, int debug);
int vhexclude(const char *url);
int vuexclude(const char *user);
int is_indexonly(void);
void free_exclude(void);

// getconf.c
void getconf(void);

// grepday.c
void greport_day(const char *user);
void greport_cleanup(void);

// html.c
void htmlrel(void);

// indexonly.c
void index_only(const char *dirname,int debug);

// ip2name.c
void ip2name(char *ip,int ip_len);
void name2ip(char *name);

// language.c
void language_load(const char *language);

// lastlog.c
void mklastlog(const char *outdir);

// index.c
void make_index(void);

// realtime.c
void realtime(void);

// repday.c
void report_day(const char *user);

// report.c
void gravatmp(const char *oldaccuser, const char *oldurl, long long int nacc, long long int nbytes, const char *oldmsg, long long int nelap, int indexonly, long long int incache, long long int oucache);
void gerarel(void);

// siteuser.c
void siteuser(void);

// smartfilter.c
void smartfilter_report(void);

// sort.c
void sort_users_log(const char *tmp, int debug);
void tmpsort(void);

// splitlog.c
void splitlog(const char *arq, char *df, int dfrom, int duntil, char *convert);

// squidguard_log.c
void squidguard_log(void);

// squidguard_report.c
void squidguard_report(void);

// topsites.c
void topsites(void);

// topuser.c
void topuser(void);

// totday.c
void day_totalize(const char *tmp, const char *user, int indexonly);

// totger.c
int totalger(const char *dirname, int debug, const char *outdir);

// usage.c
void usage(const char *prog);

// useragent.c
void useragent(void);

// util.c
void getword_start(struct getwordstruct *gwarea, const char *line);
void getword_restart(struct getwordstruct *gwarea);
int getword(char *word, int limit, struct getwordstruct *gwarea, int stop);
int getword_multisep(char *word, int limit, struct getwordstruct *gwarea, int stop);
int getword_skip(int limit, struct getwordstruct *gwarea, int stop);
int getword_atoll(long long int *number, struct getwordstruct *gwarea, int stop);
long long int my_atoll (const char *nptr);
int is_absolute(const char *path);
void name_month(char *month,int month_len);
void conv_month_name(char *month);
void buildymd(const char *dia, const char *mes, const char *ano, char *wdata);
void date_from(char *date, char *dfrom, char *duntil);
int getnumlist( char *, numlist *, const int, const int );
void fixip(char *ip);
char *fixnum(long long int value, int n);
char *fixnum2(long long int value, int n);
void fixnone(char *str);
void fixper(char *tbuf, char *period, const char *duntil);
char *fixtime(long int elap);
void fixendofline(char *str);
void show_info(FILE *fp_ou);
void show_sarg(FILE *fp_ou, const char *ind);
void write_logo_image(FILE *fp_ou);
void write_html_header(FILE *fp_ou, const char * ind);
void write_html_trailer(FILE *fp_ou);
void output_html_string(FILE *fp_ou,const char *str);
void subs(char *str, int size, char *from, char *to);
void conv_month(char *month);
void debuga(const char *msg,...);
void debugaz(const char *head, const char *msg);
void my_lltoa(unsigned long long int n, char s[], int len);
char *get_size(const char *path, const char *file);
void url_module(const char *url, char *w2);
void strip_latin(char *line);
char *buildtime(long long int elap);
void obtdate(const char *dirname, const char *name, char *data);
void formatdate(char *date,int date_size,int year,int month,int day,int hour,int minute,int second,int dst);
void obtuser(const char *dirname, const char *name, char *tuser);
void obttotal(const char *dirname, const char *name, char *tbytes, const char *tuser, char *media);
void version(void);
int vercode(const char *code);
void load_excludecodes(const char *ExcludeCodes);
void free_excludecodes(void);
void my_mkdir(const char *name);
int testvaliduserchar(const char *user);
char *strlow(char *string);
char *strup(char *string);
void builddia(char *dia, const char *mes, const char *ano, const char *df, char *wdata);
void vrfydir(const char *per1, const char *addr, const char *site, const char *us, const char *form);
void gperiod(const char *dirname, const char *period);
void removetmp(const char *outdir);
void zdate(char *ftime,int ftimesize, const char *DateFormat);
void baddata(void);
char *get_param_value(const char *param,char *line);
void read_usertab(const char *UserTabFile);
void get_usertab_name(const char *user,char *name,int namelen);
int compar( const void *, const void * );
void unlinkdir(const char *dir,int contentonly);
